# osxmetadata Authors

## Rhet Turnbull

 * Personal website: https://github.com/RhetTbull
 * EMail: rturnbull+git [:AT:] gmail [:DOT:] com
 * Location: California, USA
 * Twitter: @RhetTurnbull
 * Github: RhetTbull
